@@ -93,7 +93,7 @@ public:
     Private(KToolBar *qq)
         : q(qq),
           isMainToolBar(false),
-#ifndef KDE_NO_DEPRECATED
+#ifndef KXMLGUI_NO_DEPRECATED
           enableContext(true),
 #endif
           unlockedMovable(true),
@@ -146,10 +146,11 @@ public:
     static Qt::ToolButtonStyle toolButtonStyleFromString(const QString &style);
     static QString toolButtonStyleToString(Qt::ToolButtonStyle);
     static Qt::ToolBarArea positionFromString(const QString &position);
+    static Qt::ToolButtonStyle toolButtonStyleSetting();
 
     KToolBar *q;
     bool isMainToolBar : 1;
-#ifndef KDE_NO_DEPRECATED
+#ifndef KXMLGUI_NO_DEPRECATED
     bool enableContext : 1;
 #endif
     bool unlockedMovable : 1;
@@ -242,7 +243,6 @@ void KToolBar::Private::init(bool readConfig, bool _isMainToolBar)
     loadKDESettings();
 
     // also read in our configurable settings (for non-xmlgui toolbars)
-    // KDE5: we can probably remove this, if people save settings then they load them too, e.g. using KMainWindow's autosave.
     if (readConfig) {
         KConfigGroup cg(KSharedConfig::openConfig(), QString());
         q->applySettings(cg);
@@ -514,12 +514,19 @@ void KToolBar::Private::slotAppearanceChanged()
     applyCurrentSettings();
 }
 
+Qt::ToolButtonStyle KToolBar::Private::toolButtonStyleSetting()
+{
+    KConfigGroup group(KSharedConfig::openConfig(), "Toolbar style");
+    const QString fallback = KToolBar::Private::toolButtonStyleToString(Qt::ToolButtonTextBesideIcon);
+    return KToolBar::Private::toolButtonStyleFromString(group.readEntry("ToolButtonStyle", fallback));
+}
+
 void KToolBar::Private::loadKDESettings()
 {
     iconSizeSettings[Level_KDEDefault] = q->iconSizeDefault();
 
     if (isMainToolBar) {
-        toolButtonStyleSettings[Level_KDEDefault] = q->toolButtonStyleSetting();
+        toolButtonStyleSettings[Level_KDEDefault] = toolButtonStyleSetting();
     } else {
         const QString fallBack = toolButtonStyleToString(Qt::ToolButtonTextBesideIcon);
         /**
@@ -831,14 +838,14 @@ KToolBar::~KToolBar()
     delete d;
 }
 
-#ifndef KDE_NO_DEPRECATED
+#ifndef KXMLGUI_NO_DEPRECATED
 void KToolBar::setContextMenuEnabled(bool enable)
 {
     d->enableContext = enable;
 }
 #endif
 
-#ifndef KDE_NO_DEPRECATED
+#ifndef KXMLGUI_NO_DEPRECATED
 bool KToolBar::contextMenuEnabled() const
 {
     return d->enableContext;
@@ -849,8 +856,6 @@ void KToolBar::saveSettings(KConfigGroup &cg)
 {
     Q_ASSERT(!cg.name().isEmpty());
 
-    cg.deleteEntry("Hidden"); // remove old key to avoid bugs from the compat code in applySettings. KDE5: remove.
-
     const int currentIconSize = iconSize().width();
     //qDebug() << objectName() << currentIconSize << d->iconSizeSettings.toString() << "defaultValue=" << d->iconSizeSettings.defaultValue();
     if (!cg.hasDefault("IconSize") && currentIconSize == d->iconSizeSettings.defaultValue()) {
@@ -871,7 +876,7 @@ void KToolBar::saveSettings(KConfigGroup &cg)
     }
 }
 
-#ifndef KDE_NO_DEPRECATED
+#ifndef KXMLGUI_NO_DEPRECATED
 void KToolBar::setXMLGUIClient(KXMLGUIClient *client)
 {
     d->xmlguiClients.clear();
@@ -891,7 +896,7 @@ void KToolBar::removeXMLGUIClient(KXMLGUIClient *client)
 
 void KToolBar::contextMenuEvent(QContextMenuEvent *event)
 {
-#ifndef KDE_NO_DEPRECATED
+#ifndef KXMLGUI_NO_DEPRECATED
     if (mainWindow() && d->enableContext) {
         QPointer<KToolBar> guard(this);
         const QPoint globalPos = event->globalPos();
@@ -908,13 +913,6 @@ void KToolBar::contextMenuEvent(QContextMenuEvent *event)
     QToolBar::contextMenuEvent(event);
 }
 
-Qt::ToolButtonStyle KToolBar::toolButtonStyleSetting()
-{
-    KConfigGroup group(KSharedConfig::openConfig(), "Toolbar style");
-    const QString fallback = Private::toolButtonStyleToString(Qt::ToolButtonTextBesideIcon);
-    return KToolBar::Private::toolButtonStyleFromString(group.readEntry("ToolButtonStyle", fallback));
-}
-
 void KToolBar::loadState(const QDomElement &element)
 {
     QMainWindow *mw = mainWindow();
@@ -1065,22 +1063,9 @@ void KToolBar::saveState(QDomElement &current) const
 }
 
 // called by KMainWindow::applyMainWindowSettings to read from the user settings
-void KToolBar::applySettings(const KConfigGroup &cg, bool forceGlobal)
+void KToolBar::applySettings(const KConfigGroup &cg)
 {
     Q_ASSERT(!cg.name().isEmpty());
-    Q_UNUSED(forceGlobal); // KDE5: remove
-
-    // a small leftover from kde3: separate bool for hidden/shown. But it's also part of saveMainWindowSettings,
-    // it is not really useful anymore, except in the unlikely case where someone would call this by hand.
-    // KDE5: remove the block below
-    if (cg.hasKey("Hidden")) {
-        const bool hidden = cg.readEntry("Hidden", false);
-        if (hidden) {
-            hide();
-        } else {
-            show();
-        }
-    }
 
     if (cg.hasKey("IconSize")) {
         d->iconSizeSettings[Level_UserSettings] = cg.readEntry("IconSize", 0);
